


from odoo import models, fields, api
from odoo.exceptions import UserError, ValidationError,Warning
from psycopg2 import sql, DatabaseError

from werkzeug import utils


import os.path
from google.oauth2 import service_account
from googleapiclient.discovery import build
from datetime import datetime, timedelta


# IF YOU MODIFY THE SCOPE DELETE THE TOKEN.TXT FILE
SCOPES = ['https://www.googleapis.com/auth/calendar']
SERVICE_ACCOUNT_FILE = '/usr/lib/python3/dist-packages/odoo/kalachakra_module/kalachakra/models/creds.json' # You should make it an environment variable
SUBJECT = 'kalachakra-srv@kalachakra-351613.iam.gserviceaccount.com'


class EventTagCategory(models.Model):
    _inherit = "event.tag.category"
    _description = 'Event tag category'

    calendar_id=fields.Char('google calendar id')

class EventEvent(models.Model):
    _inherit = "event.event"
    _description = 'Event'

    calendar_id=fields.Char('calendar id')
    event_id=fields.Char('event id')

    def add_event_to_google_agenda(self):
       credentials = service_account.Credentials.from_service_account_file(SERVICE_ACCOUNT_FILE, scopes=SCOPES)
       delegated_credentials = credentials.with_subject(SUBJECT)
       service = build('calendar', 'v3', credentials=delegated_credentials)
                
       d = datetime.utcnow().date()
       tomorrow = datetime(d.year, d.month, d.day, 10)+timedelta(days=1)
       start = tomorrow.isoformat()
       end = (tomorrow + timedelta(hours=1)).isoformat()
       
       start=self.date_begin.isoformat()
       end=self.date_end.isoformat()
       diff_date=self.date_end-self.date_begin
       if diff_date.days>0:
        date_param=self.date_begin.strftime('%Y-%m-%d')+'-'+self.date_end.strftime('%Y-%m-%d')
       else:
        date_param=self.date_begin.strftime('%Y-%m-%d')+'-'+str(self.id)

       name_param=self.name.replace(' ','-')
       name_param=name_param.replace('\'','-')
       description='<a href="'+self.env['ir.config_parameter'].get_param('web.base.url')+'/event/'+name_param+'-'+date_param+'/register">Click here to register</a>'
       #str(self.date_begin.year())+'-'+str(self.date_begin.month())+'-'+self.date_begin.day()
       
       body={"summary": self.name, 
            "description": description,
            "start": {"dateTime": start, "timeZone": 'Asia/Karachi'}, 
            "end": {"dateTime": end, "timeZone": 'Asia/Karachi'},
            }

        #recherche de l'id calendar lié à l'étiquette de l'événément
       calendar_id=self.tag_ids.category_id.calendar_id
       if calendar_id:
            event = service.events().insert(calendarId=calendar_id, body=body).execute()

            self.event_id=event['id']
       else:
            raise Warning('no calendar id, please check configuration tags') 

    def remove_event_to_google_agenda(self):
       credentials = service_account.Credentials.from_service_account_file(SERVICE_ACCOUNT_FILE, scopes=SCOPES)
       delegated_credentials = credentials.with_subject(SUBJECT)
       service = build('calendar', 'v3', credentials=delegated_credentials)
       

        #recherche de l'id calendar lié à l'étiquette de l'événément
       calendar_id=self.tag_ids.category_id.calendar_id
       if calendar_id:
           service.events().delete(calendarId=calendar_id, eventId=self.event_id).execute()

           self.event_id=False
       else:
           raise Warning('no calendar id, please check configuration tags')  
    